@@ -14,15 +14,15 @@
 #ifndef CAML_CONFIG_H
 #define CAML_CONFIG_H
 
-#undef ARCH_SIXTYFOUR
+#define ARCH_SIXTYFOUR
 #define SIZEOF_INT 4
-#define SIZEOF_LONG 4
-#define SIZEOF_PTR 4
+#define SIZEOF_LONG 8
+#define SIZEOF_PTR 8
 #define SIZEOF_SHORT 2
 #define SIZEOF_LONGLONG 8
-#define ARCH_BIG_ENDIAN
-#define ARCH_ALIGN_DOUBLE
-#define ARCH_ALIGN_INT64
+#undef ARCH_BIG_ENDIAN
+#undef ARCH_ALIGN_DOUBLE
+#undef ARCH_ALIGN_INT64
 #undef NONSTANDARD_DIV_MOD
 #define ASM_CFI_SUPPORTED
 #define OCAML_OS_TYPE "Unix"
@@ -71,8 +71,10 @@
 #define SUPPORT_DYNAMIC_LINKING
 #define HAS_MMAP
 #define HAS_PWRITE
+#define HAS_NANOSECOND_STAT 1
 #define HAS_MKSTEMP
 #define HAS_NICE
+#define HAS_STACK_OVERFLOW_DETECTION
 #define HAS_SIGWAIT
 #define HAS_LIBBFD
 
