@@ -11,18 +11,30 @@
 /*                                                                     */
 /***********************************************************************/
 
-/* $Id: unixsupport.h 12488 2012-05-28 11:31:30Z frisch $ */
+#ifndef CAML_UNIXSUPPORT_H
+#define CAML_UNIXSUPPORT_H
 
 #ifdef HAS_UNISTD
 #include <unistd.h>
 #endif
 
+#ifdef __cplusplus
+extern "C" {
+#endif
+
 #define Nothing ((value) 0)
 
 extern value unix_error_of_code (int errcode);
+extern int code_of_unix_error (value error);
 extern void unix_error (int errcode, char * cmdname, value arg) Noreturn;
 extern void uerror (char * cmdname, value arg) Noreturn;
 
 #define UNIX_BUFFER_SIZE 65536
 
 #define DIR_Val(v) *((DIR **) &Field(v, 0))
+
+#ifdef __cplusplus
+}
+#endif
+
+#endif /* CAML_UNIXSUPPORT_H */
